@@ -1,54 +1,59 @@
 
 var assert = require('assert')
 var cookieParser = require('..')
+var deepEqual = require('deep-equal')
 var http = require('http')
 var request = require('supertest')
 var signature = require('cookie-signature')
 
-describe('cookieParser()', function(){
+describe('cookieParser()', function () {
   var server
-  before(function(){
+  before(function () {
     server = createServer('keyboard cat')
   })
 
-  it('should export JSONCookies function', function(){
+  after(function (done) {
+    server.close(done)
+  })
+
+  it('should export JSONCookies function', function () {
     assert(typeof cookieParser.JSONCookies, 'function')
   })
 
-  describe('when no cookies are sent', function(){
-    it('should default req.cookies to {}', function(done){
+  describe('when no cookies are sent', function () {
+    it('should default req.cookies to {}', function (done) {
       request(server)
-      .get('/')
-      .expect(200, '{}', done)
+        .get('/')
+        .expect(200, '{}', done)
     })
 
-    it('should default req.signedCookies to {}', function(done){
+    it('should default req.signedCookies to {}', function (done) {
       request(server)
-      .get('/signed')
-      .expect(200, '{}', done)
+        .get('/signed')
+        .expect(200, '{}', done)
     })
   })
 
-  describe('when cookies are sent', function(){
-    it('should populate req.cookies', function(done){
+  describe('when cookies are sent', function () {
+    it('should populate req.cookies', function (done) {
       request(server)
-      .get('/')
-      .set('Cookie', 'foo=bar; bar=baz')
-      .expect(200, '{"foo":"bar","bar":"baz"}', done)
+        .get('/')
+        .set('Cookie', 'foo=bar; bar=baz')
+        .expect(200, '{"foo":"bar","bar":"baz"}', done)
     })
 
-    it('should inflate JSON cookies', function(done){
+    it('should inflate JSON cookies', function (done) {
       request(server)
-      .get('/')
-      .set('Cookie', 'foo=j:{"foo":"bar"}')
-      .expect(200, '{"foo":{"foo":"bar"}}', done)
+        .get('/')
+        .set('Cookie', 'foo=j:{"foo":"bar"}')
+        .expect(200, '{"foo":{"foo":"bar"}}', done)
     })
 
-    it('should not inflate invalid JSON cookies', function(done){
+    it('should not inflate invalid JSON cookies', function (done) {
       request(server)
-      .get('/')
-      .set('Cookie', 'foo=j:{"foo":')
-      .expect(200, '{"foo":"j:{\\"foo\\":"}', done)
+        .get('/')
+        .set('Cookie', 'foo=j:{"foo":')
+        .expect(200, '{"foo":"j:{\\"foo\\":"}', done)
     })
   })
 
@@ -69,51 +74,51 @@ describe('cookieParser()', function(){
       })
 
       request(server)
-      .get('/')
-      .set('Cookie', 'foo=bar; bar=baz')
-      .expect(200, '{"fizz":"buzz"}', done)
+        .get('/')
+        .set('Cookie', 'foo=bar; bar=baz')
+        .expect(200, '{"fizz":"buzz"}', done)
     })
   })
 
-  describe('when a secret is given', function(){
-    var val = signature.sign('foobarbaz', 'keyboard cat');
+  describe('when a secret is given', function () {
+    var val = signature.sign('foobarbaz', 'keyboard cat')
     // TODO: "bar" fails...
 
-    it('should populate req.signedCookies', function(done){
+    it('should populate req.signedCookies', function (done) {
       request(server)
-      .get('/signed')
-      .set('Cookie', 'foo=s:' + val)
-      .expect(200, '{"foo":"foobarbaz"}', done)
+        .get('/signed')
+        .set('Cookie', 'foo=s:' + val)
+        .expect(200, '{"foo":"foobarbaz"}', done)
     })
 
-    it('should remove the signed value from req.cookies', function(done){
+    it('should remove the signed value from req.cookies', function (done) {
       request(server)
-      .get('/')
-      .set('Cookie', 'foo=s:' + val)
-      .expect(200, '{}', done)
+        .get('/')
+        .set('Cookie', 'foo=s:' + val)
+        .expect(200, '{}', done)
     })
 
-    it('should omit invalid signatures', function(done){
+    it('should omit invalid signatures', function (done) {
       server.listen()
       request(server)
-      .get('/signed')
-      .set('Cookie', 'foo=' + val + '3')
-      .expect(200, '{}', function(err){
-        if (err) return done(err)
-        request(server)
-        .get('/')
+        .get('/signed')
         .set('Cookie', 'foo=' + val + '3')
-        .expect(200, '{"foo":"foobarbaz.CP7AWaXDfAKIRfH49dQzKJx7sKzzSoPq7/AcBBRVwlI3"}', done)
-      });
+        .expect(200, '{}', function (err) {
+          if (err) return done(err)
+          request(server)
+            .get('/')
+            .set('Cookie', 'foo=' + val + '3')
+            .expect(200, '{"foo":"foobarbaz.CP7AWaXDfAKIRfH49dQzKJx7sKzzSoPq7/AcBBRVwlI3"}', done)
+        })
     })
   })
 
   describe('when multiple secrets are given', function () {
     it('should populate req.signedCookies', function (done) {
       request(createServer(['keyboard cat', 'nyan cat']))
-      .get('/signed')
-      .set('Cookie', 'buzz=s:foobar.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE; fizz=s:foobar.JTCAgiMWsnuZpN3mrYnEUjXlGxmDi4POCBnWbRxse88')
-      .expect(200, '{"buzz":"foobar","fizz":"foobar"}', done)
+        .get('/signed')
+        .set('Cookie', 'buzz=s:foobar.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE; fizz=s:foobar.JTCAgiMWsnuZpN3mrYnEUjXlGxmDi4POCBnWbRxse88')
+        .expect(200, '{"buzz":"foobar","fizz":"foobar"}', done)
     })
   })
 
@@ -125,17 +130,17 @@ describe('cookieParser()', function(){
 
     it('should populate req.cookies', function (done) {
       request(server)
-      .get('/')
-      .set('Cookie', 'foo=bar; bar=baz')
-      .expect(200, '{"foo":"bar","bar":"baz"}', done)
+        .get('/')
+        .set('Cookie', 'foo=bar; bar=baz')
+        .expect(200, '{"foo":"bar","bar":"baz"}', done)
     })
 
     it('should not populate req.signedCookies', function (done) {
-      var val = signature.sign('foobarbaz', 'keyboard cat');
+      var val = signature.sign('foobarbaz', 'keyboard cat')
       request(server)
-      .get('/signed')
-      .set('Cookie', 'foo=s:' + val)
-      .expect(200, '{}', done)
+        .get('/signed')
+        .set('Cookie', 'foo=s:' + val)
+        .expect(200, '{}', done)
     })
   })
 })
@@ -148,7 +153,7 @@ describe('cookieParser.JSONCookie(str)', function () {
     assert.strictEqual(cookieParser.JSONCookie(42), undefined)
     assert.strictEqual(cookieParser.JSONCookie({}), undefined)
     assert.strictEqual(cookieParser.JSONCookie([]), undefined)
-    assert.strictEqual(cookieParser.JSONCookie(function(){}), undefined)
+    assert.strictEqual(cookieParser.JSONCookie(function () {}), undefined)
   })
 
   it('should return undefined for non-JSON cookie string', function () {
@@ -158,7 +163,7 @@ describe('cookieParser.JSONCookie(str)', function () {
   })
 
   it('should return object for JSON cookie string', function () {
-    assert.deepEqual(cookieParser.JSONCookie('j:{"foo":"bar"}'), { foo: 'bar' })
+    deepEqual(cookieParser.JSONCookie('j:{"foo":"bar"}'), { foo: 'bar' })
   })
 
   it('should return undefined on invalid JSON', function () {
@@ -173,7 +178,7 @@ describe('cookieParser.signedCookie(str, secret)', function () {
     assert.strictEqual(cookieParser.signedCookie(42, 'keyboard cat'), undefined)
     assert.strictEqual(cookieParser.signedCookie({}, 'keyboard cat'), undefined)
     assert.strictEqual(cookieParser.signedCookie([], 'keyboard cat'), undefined)
-    assert.strictEqual(cookieParser.signedCookie(function(){}, 'keyboard cat'), undefined)
+    assert.strictEqual(cookieParser.signedCookie(function () {}, 'keyboard cat'), undefined)
   })
 
   it('should pass through non-signed string', function () {
@@ -216,18 +221,18 @@ describe('cookieParser.signedCookie(str, secret)', function () {
 
 describe('cookieParser.signedCookies(obj, secret)', function () {
   it('should ignore non-signed strings', function () {
-    assert.deepEqual(cookieParser.signedCookies({}, 'keyboard cat'), {})
-    assert.deepEqual(cookieParser.signedCookies({ foo: 'bar' }, 'keyboard cat'), {})
+    deepEqual(cookieParser.signedCookies({}, 'keyboard cat'), {})
+    deepEqual(cookieParser.signedCookies({ foo: 'bar' }, 'keyboard cat'), {})
   })
 
   it('should include tampered strings as false', function () {
-    assert.deepEqual(cookieParser.signedCookies({ foo: 's:foobaz.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE' }, 'keyboard cat'), {
+    deepEqual(cookieParser.signedCookies({ foo: 's:foobaz.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE' }, 'keyboard cat'), {
       foo: false
     })
   })
 
   it('should include unsigned strings', function () {
-    assert.deepEqual(cookieParser.signedCookies({ foo: 's:foobar.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE' }, 'keyboard cat'), {
+    deepEqual(cookieParser.signedCookies({ foo: 's:foobar.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE' }, 'keyboard cat'), {
       foo: 'foobar'
     })
   })
@@ -237,8 +242,8 @@ describe('cookieParser.signedCookies(obj, secret)', function () {
       foo: 's:foobar.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE'
     }
 
-    assert.deepEqual(cookieParser.signedCookies(obj, 'keyboard cat'), { foo: 'foobar' })
-    assert.deepEqual(obj, {})
+    deepEqual(cookieParser.signedCookies(obj, 'keyboard cat'), { foo: 'foobar' })
+    deepEqual(obj, {})
   })
 
   it('should remove tampered strings from original object', function () {
@@ -246,8 +251,8 @@ describe('cookieParser.signedCookies(obj, secret)', function () {
       foo: 's:foobaz.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE'
     }
 
-    assert.deepEqual(cookieParser.signedCookies(obj, 'keyboard cat'), { foo: false })
-    assert.deepEqual(obj, {})
+    deepEqual(cookieParser.signedCookies(obj, 'keyboard cat'), { foo: false })
+    deepEqual(obj, {})
   })
 
   it('should leave unsigned string in original object', function () {
@@ -256,8 +261,8 @@ describe('cookieParser.signedCookies(obj, secret)', function () {
       foo: 's:foobar.N5r0C3M8W+IPpzyAJaIddMWbTGfDSO+bfKlZErJ+MeE'
     }
 
-    assert.deepEqual(cookieParser.signedCookies(obj, 'keyboard cat'), { foo: 'foobar' })
-    assert.deepEqual(obj, { fizz: 'buzz' })
+    deepEqual(cookieParser.signedCookies(obj, 'keyboard cat'), { foo: 'foobar' })
+    deepEqual(obj, { fizz: 'buzz' })
   })
 
   describe('when secret is an array', function () {
@@ -267,7 +272,7 @@ describe('cookieParser.signedCookies(obj, secret)', function () {
         fizz: 's:foobar.JTCAgiMWsnuZpN3mrYnEUjXlGxmDi4POCBnWbRxse88'
       }
 
-      assert.deepEqual(cookieParser.signedCookies(obj, [ 'keyboard cat', 'nyan cat' ]), {
+      deepEqual(cookieParser.signedCookies(obj, [ 'keyboard cat', 'nyan cat' ]), {
         buzz: 'foobar',
         fizz: 'foobar'
       })
@@ -275,17 +280,17 @@ describe('cookieParser.signedCookies(obj, secret)', function () {
   })
 })
 
-function createServer(secret) {
+function createServer (secret) {
   var _parser = cookieParser(secret)
-  return http.createServer(function(req, res){
-    _parser(req, res, function(err){
+  return http.createServer(function (req, res) {
+    _parser(req, res, function (err) {
       if (err) {
         res.statusCode = 500
         res.end(err.message)
         return
       }
 
-      var cookies = '/signed' === req.url
+      var cookies = req.url === '/signed'
         ? req.signedCookies
         : req.cookies
       res.end(JSON.stringify(cookies))
